[tor-commits] [tor/master] Renamed "onionskins_completed" to "onionskins_assigned"

nickm at torproject.org nickm at torproject.org
Fri Mar 28 03:00:34 UTC 2014


commit 6ad7f3417c80f195e382e98a0fe80371bc9b8c99
Author: Nick Mathewson <nickm at torproject.org>
Date:   Thu Mar 27 22:57:53 2014 -0400

    Renamed "onionskins_completed" to "onionskins_assigned"
    
    This improves the accuracy of the function/variable names.
---
 src/or/cpuworker.c |    2 +-
 src/or/rephist.c   |   16 ++++++++--------
 src/or/rephist.h   |    2 +-
 3 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/src/or/cpuworker.c b/src/or/cpuworker.c
index ecf0d20..209274d 100644
--- a/src/or/cpuworker.c
+++ b/src/or/cpuworker.c
@@ -686,7 +686,7 @@ assign_onionskin_to_cpuworker(connection_t *cpuworker,
     }
 
     if (connection_or_digest_is_known_relay(circ->p_chan->identity_digest))
-      rep_hist_note_circuit_handshake_completed(onionskin->handshake_type);
+      rep_hist_note_circuit_handshake_assigned(onionskin->handshake_type);
 
     should_time = should_time_request(onionskin->handshake_type);
     memset(&req, 0, sizeof(req));
diff --git a/src/or/rephist.h b/src/or/rephist.h
index de82474..df01ae6 100644
--- a/src/or/rephist.h
+++ b/src/or/rephist.h
@@ -97,7 +97,7 @@ time_t rep_hist_conn_stats_write(time_t now);
 void rep_hist_conn_stats_term(void);
 
 void rep_hist_note_circuit_handshake_requested(uint16_t type);
-void rep_hist_note_circuit_handshake_completed(uint16_t type);
+void rep_hist_note_circuit_handshake_assigned(uint16_t type);
 void rep_hist_log_circuit_handshake_stats(time_t now);
 
 void rep_hist_free_all(void);





More information about the tor-commits mailing list
diff --git a/src/or/rephist.c b/src/or/rephist.c
index 16e16ab..87f930a 100644
--- a/src/or/rephist.c
+++ b/src/or/rephist.c
@@ -2992,11 +2992,11 @@ rep_hist_conn_stats_write(time_t now)
 }
 
 /** Internal statistics to track how many requests of each type of
  * handshake we've received, and how many we've completed. Useful for
  * seeing trends in cpu load.
  * @{ */
 static int onion_handshakes_requested[MAX_ONION_HANDSHAKE_TYPE+1] = {0};
-static int onion_handshakes_completed[MAX_ONION_HANDSHAKE_TYPE+1] = {0};
+static int onion_handshakes_assigned[MAX_ONION_HANDSHAKE_TYPE+1] = {0};
 /**@}*/
 
 /** A new onionskin (using the <b>type</b> handshake) has arrived. */
@@ -3010,10 +3010,10 @@ rep_hist_note_circuit_handshake_requested(uint16_t type)
 /** We've sent an onionskin (using the <b>type</b> handshake) to a
  * cpuworker. */
 void
-rep_hist_note_circuit_handshake_completed(uint16_t type)
+rep_hist_note_circuit_handshake_assigned(uint16_t type)
 {
   if (type <= MAX_ONION_HANDSHAKE_TYPE)
-    onion_handshakes_completed[type]++;
+    onion_handshakes_assigned[type]++;
 }
 
 /** Log our onionskin statistics since the last time we were called. */
@@ -3023,11 +3023,11 @@ rep_hist_log_circuit_handshake_stats(time_t now)
   (void)now;
   log_notice(LD_HEARTBEAT, "Circuit handshake stats since last time: "
              "%d/%d TAP, %d/%d NTor.",
-             onion_handshakes_completed[ONION_HANDSHAKE_TYPE_TAP],
+             onion_handshakes_assigned[ONION_HANDSHAKE_TYPE_TAP],
              onion_handshakes_requested[ONION_HANDSHAKE_TYPE_TAP],
-             onion_handshakes_completed[ONION_HANDSHAKE_TYPE_NTOR],
+             onion_handshakes_assigned[ONION_HANDSHAKE_TYPE_NTOR],
              onion_handshakes_requested[ONION_HANDSHAKE_TYPE_NTOR]);
-  memset(onion_handshakes_completed, 0, sizeof(onion_handshakes_completed));
+  memset(onion_handshakes_assigned, 0, sizeof(onion_handshakes_assigned));
   memset(onion_handshakes_requested, 0, sizeof(onion_handshakes_requested));
 }
 
@@ -2992,11 +2992,11 @@ rep_hist_conn_stats_write(time_t now)
 
 /** Internal statistics to track how many requests of each type of
- * handshake we've received, and how many we've completed. Useful for
- * seeing trends in cpu load.
+ * handshake we've received, and how many we've assigned to cpuworkers.
+ * Useful for seeing trends in cpu load.
  * @{ */
 static int onion_handshakes_requested[MAX_ONION_HANDSHAKE_TYPE+1] = {0};